function vlna2_demo(A,T,lambda,k)
% function vlna2_demo(A,T,lambda,k)
% skladani dvou vln, zdroje jsou od seba k nasobek vlnove delky
% A - amplituda
% T - perioda
% lambda - vlnova delka
%
% priklad pouziti: vlnaě_demo(1,1,1,1)
% priklad pouziti: vlnaě_demo(1,1,1,0.5)
%


x=linspace(0,k*lambda,201); % k*lambda - vzdalenost zdroju
y0=zeros(size(x));          % nulova funkce na zacatku
omega=2*pi/T;               % uhlova rychlost
c=lambda/T;                 % rychlost sireni vlny (take c=lambda*omega/(2pi) )
t=0;
arg=x-c*t;
y=y0;
x1=x(1);
x2=x(end);
plot(x,y);
axis([x1,x2,-2*A,2*A]);
disp('Neco stiskni!')
pause
for t=linspace(0,6*T,601)
    arg1=omega*(t-x/c);
    arg1=max(arg1,0);
    arg2=omega*(t-(x2-x)/c);
    arg2=max(arg2,0);
    y1=A*sin(arg1);
    y2=A*sin(arg2);
    plot(x,y1+y2);
    axis([x(1),x(end),-2*A,2*A]);
    pause(0.1);
end